from fastmcp import FastMCP
from os import environ

from mcp_windows.media import mcp as media_mcp
from mcp_windows.notifications import mcp as notifications_mcp
from mcp_windows.window_management import mcp as window_management_mcp
from mcp_windows.monitors import mcp as monitors_mcp

sep = environ.get("FASTMCP_TOOL_SEPARATOR", "_")

mcp: FastMCP = FastMCP(
    name="windows",
)

mcp.mount("media", media_mcp, tool_separator=sep)
mcp.mount("notifications", notifications_mcp, tool_separator=sep)
mcp.mount("window_management", window_management_mcp, tool_separator=sep)
mcp.mount("monitors", monitors_mcp, tool_separator=sep)



import ctypes
import win32con
import win32gui

from fastmcp import FastMCP

mcp: FastMCP = FastMCP(
    name="monitors",
)

@mcp.tool("sleep_monitors")
async def sleep_monitors() -> str:
    """Put all monitors to sleep."""
    try:
        ctypes.windll.user32.SendMessageW(
            win32con.HWND_BROADCAST,
            win32con.WM_SYSCOMMAND,
            win32con.SC_MONITORPOWER,
            2  # 2 = power off
        )
        return "Monitors put to sleep"
    except Exception as e:
        return f"Failed to sleep monitors: {type(e).__name__}: {e}"

@mcp.tool("wake_monitors")
async def wake_monitors() -> str:
    """Wake up sleeping monitors."""
    try:
        # This is dumb, but moving the mouse 1px wakes monitors
        x, y = win32gui.GetCursorPos()
        ctypes.windll.user32.SetCursorPos(x, y + 1)
        ctypes.windll.user32.SetCursorPos(x, y)
        return "Monitors woken up"
    except Exception as e:
        return f"Failed to wake monitors: {type(e).__name__}: {e}"



import json
from fastmcp import FastMCP
from winrt.windows.media.control import GlobalSystemMediaTransportControlsSessionManager as MediaManager, GlobalSystemMediaTransportControlsSessionMediaProperties as MediaProperties
from winrt.windows.foundation import IAsyncOperation

mcp: FastMCP = FastMCP(
    name="Media",
)

@mcp.tool("get_media_sessions")
async def get_media_sessions() -> str:
    """List all media playback sessions using windows media control API."""

    manager_op: IAsyncOperation = MediaManager.request_async()
    manager = await manager_op
    sessions = manager.get_sessions()

    output = {}
    for session in sessions:
        props_op = session.try_get_media_properties_async()
        props: MediaProperties = await props_op
        app_id = session.source_app_user_model_id

        output[app_id] = {
            "title": props.title or "unknown",
            "artist": props.artist or "unknown",
            "album_title": props.album_title or "unknown",
        }
    
    return json.dumps(output)

@mcp.tool("pause")
async def pause(app_id: str) -> str:
    """Pause the media playback for a given app_id using windows media control API."""

    manager_op: IAsyncOperation[MediaManager] = \
    MediaManager.request_async()
    manager: MediaManager = await manager_op

    sessions = manager.get_sessions()
    for session in sessions:
        if session.source_app_user_model_id.lower() == app_id.lower():
            playback_info = session.get_playback_info()
            if playback_info.controls.is_pause_enabled:
                await session.try_pause_async()
                return "Paused"
            else:
                return "Pause not available"
            
    return "Session not found"

@mcp.tool("play")
async def play(app_id: str) -> str:
    """Play the media playback for a given app_id using windows media control API."""

    manager_op: IAsyncOperation[MediaManager] = \
    MediaManager.request_async()
    manager: MediaManager = await manager_op

    sessions = manager.get_sessions()
    for session in sessions:
        if session.source_app_user_model_id.lower() == app_id.lower():
            playback_info = session.get_playback_info()
            if playback_info.controls.is_play_enabled:
                await session.try_play_async()
                return "Playing"
            else:
                return "Play not available"
            
    return "Session not found"